Index: jackrabbit-api/src/main/java/org/apache/jackrabbit/api/observation/ExtendedEvent.java
===================================================================
--- jackrabbit-api/src/main/java/org/apache/jackrabbit/api/observation/ExtendedEvent.java	(revision 0)
+++ jackrabbit-api/src/main/java/org/apache/jackrabbit/api/observation/ExtendedEvent.java	(revision 0)
@@ -0,0 +1,35 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.jackrabbit.api.observation;
+
+import javax.jcr.observation.Event;
+
+/**
+ * This is an extension of the event interface which provides
+ * a method to detect whether the changes happened on locally
+ * or remotely in a clustered environment.
+ */
+public interface ExtendedEvent extends Event {
+
+    /**
+     * Return a flag indicating whether this is an externally generated event.
+     *
+     * @return <code>true</code> if this is an external event;
+     *         <code>false</code> otherwise
+     */
+    boolean isExternal();
+}

Index: jackrabbit-core/src/main/java/org/apache/jackrabbit/core/observation/EventImpl.java
===================================================================
--- jackrabbit-core/src/main/java/org/apache/jackrabbit/core/observation/EventImpl.java	(revision 679081)
+++ jackrabbit-core/src/main/java/org/apache/jackrabbit/core/observation/EventImpl.java	(working copy)
@@ -16,6 +16,7 @@
  */
 package org.apache.jackrabbit.core.observation;
 
+import org.apache.jackrabbit.api.observation.ExtendedEvent;
 import org.apache.jackrabbit.core.NodeId;
 import org.apache.jackrabbit.core.SessionImpl;
 import org.apache.jackrabbit.spi.commons.conversion.MalformedPathException;
@@ -28,9 +29,10 @@
 import javax.jcr.observation.Event;
 
 /**
  * Implementation of the {@link javax.jcr.observation.Event} interface.
  */
-public final class EventImpl implements Event {
+public final class EventImpl implements ExtendedEvent {
 
     /**
      * Logger instance for this class
@@ -144,6 +146,7 @@
      *
      * @return <code>true</code> if this is an external event;
      *         <code>false</code> otherwise
+     * @see ExtendedEvent#isExternal()
      */
     public boolean isExternal() {
         return eventState.isExternal();
@@ -28,9 +29,10 @@
 
 /**
- * Implementation of the {@link javax.jcr.observation.Event} interface.
+ * Implementation of the {@link javax.jcr.observation.Event} and
+ * the {@link ExtendedEvent} interface.
  */